@@ -1,4 +1,3 @@
-{-# LANGUAGE CPP                #-}
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE DeriveFoldable     #-}
 {-# LANGUAGE DeriveFunctor      #-}
@@ -7,18 +6,6 @@
 {-# LANGUAGE FlexibleContexts   #-}
 {-# LANGUAGE OverloadedStrings  #-}
 {-# LANGUAGE Safe               #-}
-
-#if MIN_VERSION_base(4,9,0)
-#define LIFTED_FUNCTOR_CLASSES 1
-#else
-#if MIN_VERSION_transformers (0,5,0)
-#define LIFTED_FUNCTOR_CLASSES 1
-#else
-#if MIN_VERSION_transformers_compat(0,5,0) && !MIN_VERSION_transformers(0,4,0)
-#define LIFTED_FUNCTOR_CLASSES 1
-#endif
-#endif
-#endif
 module Data.Functor.These (
     These1 (..),
     ) where
@@ -37,20 +24,12 @@ import Prelude
 import qualified Data.Foldable  as F
 import qualified Data.Foldable1 as F1
 
-#if MIN_VERSION_deepseq(1,4,3)
 import Control.DeepSeq (NFData (..), NFData1 (..))
-#else
-import Control.DeepSeq (NFData (..))
-#endif
 
-#if __GLASGOW_HASKELL__ >= 706
 import GHC.Generics (Generic1)
-#endif
 
-#if __GLASGOW_HASKELL__ >= 708
 import Data.Data     (Data)
 import Data.Typeable (Typeable)
-#endif
 
 -------------------------------------------------------------------------------
 -- These1
@@ -60,21 +39,13 @@ data These1 f g a
     = This1 (f a)
     | That1 (g a)
     | These1 (f a) (g a)
-  deriving (Functor, Foldable, Traversable, Generic
-#if __GLASGOW_HASKELL__ >= 706
-    , Generic1
-#endif
-#if __GLASGOW_HASKELL__ >= 708
-    , Typeable, Data
-#endif
-    )
+  deriving (Functor, Foldable, Traversable, Generic, Generic1, Typeable, Data)
 
 -------------------------------------------------------------------------------
 -- Eq1
 -------------------------------------------------------------------------------
 
 instance (Eq1 f, Eq1 g) => Eq1 (These1 f g) where
-#ifdef LIFTED_FUNCTOR_CLASSES
     liftEq eq (This1 f)    (This1 f')     = liftEq eq f f'
     liftEq eq (That1 g)    (That1 g')     = liftEq eq g g'
     liftEq eq (These1 f g) (These1 f' g') = liftEq eq f f' && liftEq eq g g'
@@ -82,22 +53,12 @@ instance (Eq1 f, Eq1 g) => Eq1 (These1 f g) where
     liftEq _ This1  {} _ = False
     liftEq _ That1  {} _ = False
     liftEq _ These1 {} _ = False
-#else
-    eq1 (This1 f)    (This1 f')     = eq1 f f'
-    eq1 (That1 g)    (That1 g')     = eq1 g g'
-    eq1 (These1 f g) (These1 f' g') = eq1 f f' && eq1 g g'
-
-    eq1 This1  {} _ = False
-    eq1 That1  {} _ = False
-    eq1 These1 {} _ = False
-#endif
 
 -------------------------------------------------------------------------------
 -- Ord1
 -------------------------------------------------------------------------------
 
 instance (Ord1 f, Ord1 g) => Ord1 (These1 f g) where
-#ifdef LIFTED_FUNCTOR_CLASSES
     liftCompare  cmp (This1 f) (This1 f') = liftCompare cmp f f'
     liftCompare _cmp (This1 _) _          = LT
     liftCompare _cmp _         (This1 _)  = GT
@@ -108,26 +69,12 @@ instance (Ord1 f, Ord1 g) => Ord1 (These1 f g) where
 
     liftCompare  cmp (These1 f g) (These1 f' g') =
         liftCompare cmp f f' `mappend` liftCompare cmp g g'
-#else
-    compare1 (This1 f) (This1 f') = compare1 f f'
-    compare1 (This1 _) _          = LT
-    compare1 _         (This1 _)  = GT
-
-    compare1 (That1 g) (That1 g') = compare1 g g'
-    compare1 (That1 _) _          = LT
-    compare1 _         (That1 _)  = GT
-
-    compare1  (These1 f g) (These1 f' g') =
-        compare1 f f' `mappend` compare1 g g'
-#endif
-
 
 -------------------------------------------------------------------------------
 -- Show1
 -------------------------------------------------------------------------------
 
 instance (Show1 f, Show1 g) => Show1 (These1 f g) where
-#ifdef LIFTED_FUNCTOR_CLASSES
     liftShowsPrec sp sl d (This1 f) = showParen (d > 10)
         $ showString "This1 "
         . liftShowsPrec sp sl 11 f
@@ -139,26 +86,12 @@ instance (Show1 f, Show1 g) => Show1 (These1 f g) where
         . liftShowsPrec sp sl 11 f
         . showChar ' '
         . liftShowsPrec sp sl 11 g
-#else
-    showsPrec1 d (This1 f) = showParen (d > 10)
-        $ showString "This1 "
-        . showsPrec1 11 f
-    showsPrec1 d (That1 g) = showParen (d > 10)
-        $ showString "That1 "
-        . showsPrec1 11 g
-    showsPrec1 d (These1 f g) = showParen (d > 10)
-        $ showString "These1 "
-        . showsPrec1 11 f
-        . showChar ' '
-        . showsPrec1 11 g
-#endif
 
 -------------------------------------------------------------------------------
 -- Read1
 -------------------------------------------------------------------------------
 
 instance (Read1 f, Read1 g) => Read1 (These1 f g) where
-#ifdef LIFTED_FUNCTOR_CLASSES
     liftReadsPrec rp rl d = readParen (d > 10) $ \s0 -> do
         (t, s1) <- lex s0
         case t of
@@ -173,22 +106,6 @@ instance (Read1 f, Read1 g) => Read1 (These1 f g) where
                 (y, s3) <- liftReadsPrec rp rl 11 s2
                 return (These1 x y, s3)
             _ -> []
-#else
-    readsPrec1 d = readParen (d > 10) $ \s0 -> do
-        (t, s1) <- lex s0
-        case t of
-            "This1" -> do
-                (x, s2) <- readsPrec1 11 s1
-                return (This1 x, s2)
-            "That1" -> do
-                (y, s2) <- readsPrec1 11 s1
-                return (That1 y, s2)
-            "These1" -> do
-                (x, s2) <- readsPrec1 11 s1
-                (y, s3) <- readsPrec1 11 s2
-                return (These1 x y, s3)
-            _ -> []
-#endif
 
 -------------------------------------------------------------------------------
 -- Eq, Ord, Show, Read
@@ -248,13 +165,11 @@ instance (Read (f a), Read (g a), Read a) => Read (These1 f g a) where
 -- deepseq
 -------------------------------------------------------------------------------
 
-#if MIN_VERSION_deepseq(1,4,3)
 -- | This instance is available only with @deepseq >= 1.4.3.0@
 instance (NFData1 f, NFData1 g) => NFData1 (These1 f g) where
     liftRnf r (This1 x)    = liftRnf r x
     liftRnf r (That1 y)    = liftRnf r y
     liftRnf r (These1 x y) = liftRnf r x `seq` liftRnf r y
-#endif
 
 -- | Available always
 --
